@@ -1,8 +1,8 @@
 #' iterative proportional updating
-#' 
+#'
 #' adjust sampling weights to given totals based on household-level and/or
 #' individual level constraints
-#' 
+#'
 #' @name ipu
 #' @param inp a \code{data.frame} or \code{data.table} containing household ids
 #' (optionally), counts for household and/or personal level attributes that
@@ -28,20 +28,20 @@
 #' inp$p3 <- c(1,1,0,2,1,0,2,0)
 #' con <- list(hh1=35, hh2=65, p1=91, p2=65, p3=104)
 #' res <- ipu(inp=inp, hid="hhid", con=con, verbose=FALSE)
-#' 
+#'
 #' # more sophisticated
 #' # load sample and population data
 #' data(eusilcS)
 #' data(eusilcP)
-#' 
+#'
 #' # variable generation and preparation
 #' eusilcS$hsize <- factor(eusilcS$hsize)
-#' 
+#'
 #' # make sure, factor levels in sample and population match
 #' eusilcP$region <- factor(eusilcP$region, levels = levels(eusilcS$db040))
 #' eusilcP$gender <- factor(eusilcP$gender, levels = levels(eusilcS$rb090))
 #' eusilcP$hsize  <- factor(eusilcP$hsize , levels = levels(eusilcS$hsize))
-#' 
+#'
 #' # generate input matrix
 #' # we want to adjust to variable "db040" (region) as household variables and
 #' # variable "rb090" (gender) as individual information
@@ -50,21 +50,21 @@
 #' setkeyv(samp, "db030")
 #' hh <- samp[!duplicated(samp$db030),]
 #' hhpop <- pop[!duplicated(pop$hid),]
-#' 
+#'
 #' # reg contains for each region the number of households
 #' reg <- data.table(model.matrix(~db040 +0, data=hh))
 #' # hsize contains for each household size the number of households
 #' hsize <- data.table(model.matrix(~factor(hsize) +0, data=hh))
-#' 
+#'
 #' # aggregate persons-level characteristics per household
 #' # gender contains for each household the number of males and females
 #' gender <- data.table(model.matrix(~db030+rb090 +0, data=samp))
 #' setkeyv(gender, "db030")
 #' gender <- gender[, lapply(.SD, sum), by = key(gender)]
-#' 
+#'
 #' # bind together and use it as input
 #' inp <- cbind(reg, hsize, gender)
-#' 
+#'
 #' # the totals we want to calibrate to
 #' con <- c(
 #'   as.list(xtabs(rep(1, nrow(hhpop)) ~ hhpop$region)),
@@ -73,13 +73,13 @@
 #' )
 #' # we need to have the same names as in 'inp'
 #' names(con) <- setdiff(names(inp), "db030")
-#' 
+#'
 #' # run ipu und check results
 #' res <- ipu(inp=inp, hid="db030", con=con, verbose=TRUE)
-#' 
-#' is <- sapply(2:(ncol(res)-1), function(x) { 
+#'
+#' is <- sapply(2:(ncol(res)-1), function(x) {
 #'   sum(res[,x]*res$weights)
-#' }) 
+#' })
 #' data.frame(required=unlist(con), is=is)
 ipu <- function(inp, con, hid=NULL, eps=1e-07, verbose=FALSE) {
   if ( class(inp)[1] %in% c("data.frame", "data.table") ) {
@@ -102,9 +102,15 @@ ipu <- function(inp, con, hid=NULL, eps=1e-07, verbose=FALSE) {
   }
   w <- as.numeric(rep(1,nrow(inp)))
   con <- as.numeric(unlist(con))
-  w <- .Call("simPop_ipu_work", inp, con, w, eps=eps, verbose=ifelse(verbose, 1L, 0L), package="simPop")
+  w <- ipu_work(
+    inp = inp,
+    con = con,
+    w = w,
+    eps = eps,
+    verbose = ifelse(verbose, 1L, 0L)
+  )
   out <- cbind(hhid, inp)
   out <- as.data.frame(out)
   out$weights <- w
   invisible(out)
-}
\ No newline at end of file
+}
